# Yet Another Random Stuff API Wrapper - YARSAW

YARSAW is an Async Python API Wrapper for the [Random Stuff API](https://api-info.pgamerx.com). This module makes it simpler for you to interact with the API and is easy to implement into your application.

**Make sure to get an API Key from [here](https://api-info.pgamerx.com/register.html) before trying to access this module.**

## Changes

### `1.0`

(stable)
- Updated docs
- Renamed functions in `Client()`
    - `ai` -> `get_ai_response()`
    - `joke` -> `get_joke()`
    - `fact` -> `get_fact()`
    - `waifu` -> `get_waifu()`
    - `image` -> `get_image()`
    - `covid` -> `get_covid_stats()`
    - `weather` -> `get_weather()`

- Added new function `generate_uid()`
- Many more changes


## Documentation

Make sure to read the docs at [https://namantech.me/yarsaw](https://namantech.me/yarsaw/).

## Contributing 
To contribute, fork the repo, make your changes, then start a Pull Request in the repo.

## To-Do

- [ ] Add docstrings to functions in client
